#########
extension
#########

.. code-block:: python

    from mitm import extension

.. automodule:: mitm.extension

-----

Middlewares
***********

.. autoclass:: mitm.extension.middleware.Log

.. autoclass:: mitm.extension.middleware.HTTPLog(Log)
    
----

Protocols
*********

.. autoclass:: mitm.extension.protocol.HTTP
